# Generated by Django 3.2 on 2021-04-14 20:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0065_emailtemplate_mail_to'),
    ]

    operations = [
        migrations.RenameField(
            model_name='bestellung',
            old_name='rechnungsemail',
            new_name='email_rechnung',
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='email_rechnung',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='kmuhelper.email'),
        ),
        migrations.AddField(
            model_name='bestellung',
            name='email_lieferung',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='kmuhelper.email'),
        ),
        migrations.AddField(
            model_name='bestellung',
            name='lieferadresse_email',
            field=models.EmailField(blank=True, max_length=254, verbose_name='E-Mail Adresse'),
        ),
        migrations.AddField(
            model_name='bestellung',
            name='lieferadresse_telefon',
            field=models.CharField(blank=True, default='', max_length=50, verbose_name='Telefon'),
        ),
        migrations.AddField(
            model_name='kunde',
            name='lieferadresse_email',
            field=models.EmailField(blank=True, max_length=254, verbose_name='E-Mail Adresse'),
        ),
        migrations.AddField(
            model_name='kunde',
            name='lieferadresse_telefon',
            field=models.CharField(blank=True, default='', max_length=50, verbose_name='Telefon'),
        ),
    ]
