# Generated by Django 3.1 on 2020-10-06 16:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0038_produkt_soll_lagerbestand'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bestellung',
            name='bezahlt',
            field=models.BooleanField(default=False, help_text='Sobald eine Bestellung als bezahlt markiert wurde, können Teile der Bestellung nicht mehr bearbeitet werden!', verbose_name='Bezahlt'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='versendet',
            field=models.BooleanField(default=False, help_text='Sobald eine Bestellung als versendet markiert wurde, können Teile der Bestellung nicht mehr bearbeitet werden! Ausserdem werden die Produkte aus dem Lagerbestand entfernt.', verbose_name='Versendet'),
        ),
    ]
