# Generated by Django 3.1.7 on 2021-04-03 14:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0051_apikey'),
    ]

    operations = [
        migrations.AddField(
            model_name='bestellung',
            name='rechnungsdatum',
            field=models.DateField(blank=True, default=None, null=True, verbose_name='Rechnungsdatum'),
        ),
    ]
