{% extends 'admin/kmuhelper/change_form.html' %}

{% load admin_urls %}

{% block branding %}
    <h1 id="site-name"><a target="_top" href="{% url 'kmuhelper:home' %}">KMUHelper</a> | <a id="app-link" target="_top" href="{% url 'kmuhelper:app-index' %}">App</a></h1>
{% endblock %}

{% block breadcrumbs %}
    <div id="breadcrumbs" class="breadcrumbs" style="display: block">
        <a href="{% url 'kmuhelper:app-index' %}">KMUHelper App</a> &gt; <a href="{% url opts|admin_urlname:'changelist' %}">{% block modulename %}{{ opts.verbose_name_plural }}{% endblock %}</a> &gt; {% if change %}{{ original }}{% else %}{{ opts.verbose_name }} hinzufügen{% endif %}
    </div>
    <div id="alternate-breadcrumbs" class="breadcrumbs" style="display: none">
        <a href="{% url opts|admin_urlname:'changelist' %}">&lt; Zurück</a>
    </div>
    <script>
        if (window !== window.top) { 
            document.getElementById("breadcrumbs").style.display = "none"; 
            document.getElementById("alternate-breadcrumbs").style.display = "block";
            document.getElementById("app-link").href = "{% url 'kmuhelper:app-main' %}";
        }
    </script>
{% endblock %}

{% block object-tools %}{% endblock %}
