{% extends 'admin/kmuhelper/change_list.html' %}

{% load static %}

{% block branding %}
    <h1 id="site-name"><a target="_top" href="{% url 'kmuhelper:home' %}">KMUHelper</a> | <a id="app-link" target="_top" href="{% url 'kmuhelper:app-index' %}">App</a></h1>
{% endblock %}

{% block breadcrumbs %}
    <div id="breadcrumbs" class="breadcrumbs">
        <a href="{% url 'kmuhelper:app-index' %}">KMUHelper App</a> &gt; {% block modulename %}{{ module_name }}{% endblock %}
    </div>

    <script>
        if (window !== window.top) { 
            document.getElementById("breadcrumbs").style.display = "none";
            document.getElementById("app-link").href = "{% url 'kmuhelper:app-main' %}";
        }
    </script>
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    
    <script src="{% static 'admin/js/changelist_saveontop.js' %}"></script>
{% endblock %}
