{% extends "admin/index.html" %}
{% load static %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/kmuhelper/css/index-kmuhelper.css" %}">
{% endblock %}
