# Generated by Django 3.2 on 2021-10-05 21:03

import django.core.validators
from django.db import migrations, models
import kmuhelper.main.models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0074_alter_bestellung_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='einstellung',
            name='description',
            field=models.TextField(blank=True, default='', verbose_name='Beschreibung'),
        ),
    ]
