# Generated by Django 3.2.8 on 2021-10-07 15:27

import django.core.validators
from django.db import migrations, models
import kmuhelper.main.models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0076_alter_bestellung_zahlungskonditionen'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bestellung',
            name='zahlungskonditionen',
            field=models.CharField(default=kmuhelper.main.models.defaultzahlungskonditionen, help_text="Skonto und Zahlungsfrist nach Syntaxdefinition von Swico.\n\nBeispiel: '2:15;0:30' steht für 2% Skonto bei Zahlung innerhalb von 15 Tagen und eine Zahlungsfrist von 30 Tagen.\n\nEine Zahlungsfrist MUSS vorhanden sein und am Schluss aufgeführt werden.", max_length=16, validators=[django.core.validators.RegexValidator('^([0-9]+(\\.[0-9]+)?:[0-9]+;)*0:[0-9]+$', "Bitte benutze folgendes Format: 'p:d;p:d' - p = Skonto in %; d = Tage")], verbose_name='Zahlungskonditionen'),
        ),
    ]
