# Generated by Django 3.1.7 on 2021-04-03 17:41

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0053_bestellung_rechnungstext'),
    ]

    operations = [
        migrations.AddField(
            model_name='bestellung',
            name='rechnungstitel',
            field=models.CharField(blank=True, default='', help_text="Titel der Rechnung. Leer lassen für 'RECHNUNG'", max_length=32, verbose_name='Rechnungstitel'),
        ),
        migrations.AddField(
            model_name='bestellung',
            name='zahlungskonditionen',
            field=models.CharField(default='0:30', help_text="Skonto und Zahlfrist nach Syntaxdefinition von Swico. z.B. '2:15;0:30'", max_length=16, validators=[django.core.validators.RegexValidator('[0-9]+:[0-9]+(;[0-9]+:[0-9]+)*')], verbose_name='Zahlungskonditionen'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsdatum',
            field=models.DateField(blank=True, default=None, help_text='Datum der Rechnung. Wird auch als Startpunkt für die Zahlungskonditionen verwendet.', null=True, verbose_name='Rechnungsdatum'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungstext',
            field=models.TextField(blank=True, default='', help_text="Wird auf der Rechnung gedruckt! Unterstützt <abbr title='<b>Fett</b><u>Unterstrichen</u><i>Kursiv</i>'>XML markup</abbr>.", verbose_name='Rechnungstext'),
        ),
    ]
