# Generated by Django 3.2 on 2021-04-16 14:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0067_auto_20210415_2007'),
    ]

    operations = [
        migrations.RenameField(
            model_name='kunde',
            old_name='registrierungsemail',
            new_name='email_registriert',
        ),
    ]
