{% extends 'kmuhelper/app/base.html' %}

{% block subtitle %}Error{% endblock %}

{% block content %}
    <h1>Error</h1>
    <p>Die angeforderte Seite konnte leider nicht geladen werden!</p>
    <br>
    <h3>Mögliche Ursachen</h3>
    <ul>
        <li>Du hast keinen Zugriff auf diese Seite.</li>
        <li>Diese Seite existiert nicht.</li>
        <li>Diese Seite darf nicht in der App geöffnet werden.</li>
    </ul>
    <br>
    <a target="_top" href="{% url 'kmuhelper:app-main' %}#home">Zur Startseite</a>

    {% if user.is_anonymous %}
        <script>
            top.location.reload();
        </script>
    {% endif %}
{% endblock %}
