# Generated by Django 3.2.9 on 2021-11-22 18:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0077_alter_bestellung_zahlungskonditionen'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bestellung',
            name='lieferadresse_adresszeile1',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Adresszeile 1'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='lieferadresse_adresszeile2',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Adresszeile 2'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='lieferadresse_firma',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Firma'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='lieferadresse_nachname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Nachname'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='lieferadresse_ort',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Ort'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='lieferadresse_vorname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Vorname'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_adresszeile1',
            field=models.CharField(blank=True, default='', help_text="Strasse und Hausnummer oder 'Postfach'", max_length=250, verbose_name='Adresszeile 1'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_adresszeile2',
            field=models.CharField(blank=True, default='', help_text='Wird in QR-Rechnung NICHT verwendet!', max_length=250, verbose_name='Adresszeile 2'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_firma',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Firma'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_nachname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Nachname'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_ort',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Ort'),
        ),
        migrations.AlterField(
            model_name='bestellung',
            name='rechnungsadresse_vorname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Vorname'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='firma',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Firma'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='lieferadresse_adresszeile1',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Adresszeile 1'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='lieferadresse_adresszeile2',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Adresszeile 2'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='lieferadresse_firma',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Firma'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='lieferadresse_nachname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Nachname'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='lieferadresse_ort',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Ort'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='lieferadresse_vorname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Vorname'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='nachname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Nachname'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='rechnungsadresse_adresszeile1',
            field=models.CharField(blank=True, default='', help_text='Strasse und Hausnummer oder "Postfach"', max_length=250, verbose_name='Adresszeile 1'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='rechnungsadresse_adresszeile2',
            field=models.CharField(blank=True, default='', help_text='Wird in QR-Rechnung NICHT verwendet!', max_length=250, verbose_name='Adresszeile 2'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='rechnungsadresse_firma',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Firma'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='rechnungsadresse_nachname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Nachname'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='rechnungsadresse_ort',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Ort'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='rechnungsadresse_vorname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Vorname'),
        ),
        migrations.AlterField(
            model_name='kunde',
            name='vorname',
            field=models.CharField(blank=True, default='', max_length=250, verbose_name='Vorname'),
        ),
    ]
