# Generated by Django 3.0.4 on 2020-05-31 09:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0008_auto_20200502_1851'),
    ]

    operations = [
        migrations.AddField(
            model_name='kunde',
            name='notiz',
            field=models.TextField(blank=True, default='', verbose_name='Notiz'),
        ),
    ]
