# Generated by Django 3.0.4 on 2020-07-27 14:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kmuhelper', '0030_auto_20200720_1936'),
    ]

    operations = [
        migrations.AlterField(
            model_name='produkt',
            name='kategorien',
            field=models.ManyToManyField(related_name='produkte', through='kmuhelper.Produktkategorie', to='kmuhelper.Kategorie', verbose_name='Kategorie'),
        ),
    ]
